package Ssm::Business;

=head1 NAME

Ssm::Business - ssm2б ̳ץꥱѥ⥸塼

=head2 NOTES

$Id: Business.pm,v 1.8 2003/05/21 15:21:44 miy Exp $

=head1 SYNOPSIS

  $string = &hira2kata($string);
  $string = &kata2hira($string);

  ʤɡܸ̳ץꥱݤΩĴؿ

=head1 DESCRIPTION


=cut

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $hiragana $katakana @abbr $ascii $twoBytes $threeBytes $z_hiragana $z_katakana $z_ext);

use Exporter;
use AutoLoader qw(AUTOLOAD);

@ISA = qw(Exporter AutoLoader);
@EXPORT = qw(
);
$VERSION = do {my @r = (q$Revision: 1.8 $ =~ /\d+/g);sprintf "%d."."%02d" x $#r, @r};

use Ssm::Common;
use Jcode;

#Ѥѿ
$hiragana = 'ĤƤȤʤˤ̤ͤΤϤҤդؤۤޤߤ󤬤¤ŤǤɤФӤ֤٤ܤѤԤפڤݤä硼';
$katakana = 'ĥƥȥʥ˥̥ͥΥϥҥեإۥޥߥ󥬥¥ťǥɥХӥ֥٥ܥѥԥץڥݥå硼';

if (defined @Ssm::Config::abbr and scalar(@Ssm::Config::abbr)){
	@abbr = @Ssm::Config::abbr;
} else {
	@abbr = (
	['','','֥','',''],
	['ͭ','ͭ²','楦󥬥','楦',''],
	['','عˡ','åۥ','',''],
	['','','','',''],
	['','ˡ','ۥ','',''],
	['','ˡ','奦祦ۥ','奦',''],
	['','ˡ','祦ۥ','',''],
	);
}

$ascii = '[\x00-\x7F]';
$twoBytes = '[\x8E\xA1-\xFE][\xA1-\xFE]';
$threeBytes = '\x8F[\xA1-\xFE][\xA1-\xFE]';
$z_hiragana = '(?:\xA4[\xA1-\xF3])'; # EUC-JP ѤҤ餬
$z_katakana = '(?:\xA5[\xA1-\xF6])'; # EUC-JP ѥ
$z_ext = '(?:\xA1[\xA6\xBC\xB3\xB4])'; # EUC-JP ѥʳĥ +[]


1;
__END__

####################################################

=pod

=head2 bare_mail_chk()

=over 4

=item ǽ

ʸ󤬡᡼륢ɥ쥹Ȥå롣
ϥեϤ줿ͤΥåʤɤꡣ

=item 

ʸ1ġ

=item 

ñΥ᡼륢ɥ쥹ȽǤǤɽƤ=1
ʣΥ޶ڥ᡼륢ɥ쥹ȽǤǤɽƤ=2
᡼륢ɥ쥹˻ѤǤʸΤߤǹƤ=3
嵭ʳξ=0

=item 

unless (&bare_mail_chk($userinput) == 1){
	$errormsg = "mail address format error!";
}

=back

=cut

sub bare_mail_chk($){
	my $str = $_[0];
	if ($str){
		($str =~ /^([\w\.-]+@[\w\.-]+\.[a-zA-Z]{2,4}[\t ]*,[\t ]*)+([\w\.-]+@[\w\.-]+\.[a-zA-Z]{2,4}[\t ]*)?$/i) and return 2;
		($str =~ /^[\w\.-]+@[\w\.-]+\.[a-zA-Z]{2,4}$/i) and return 1;
		($str =~ /^[\w\.@-]+$/i) and return 3;
	}
	return 0;
}

####################################################

=pod

=head2 hira2kata()

=over 4

=item ǽ

˴ޤޤѤҤ餬ʤѥʤѴ

=item 

ʸ1ġ

=item 

Ѵʸ

=item 

$katakana = &hira2kata($hiragana)

=back

=cut

sub hira2kata($){
	my $str = shift;
	$str or return '';
	return &Ssm::Common::codeconv(Jcode->new($str)->h2z->tr($hiragana, $katakana)->euc, $main::charset);
}

####################################################

=pod

=head2 kata2hira()

=over 4

=item ǽ

˴ޤޤѥʤѤҤ餬ʤѴ

=item 

ʸ1ġ

=item 

Ѵʸ

=item 

$hiragana = &kata2hira($katakana)

=back

=cut

sub kata2hira($){
	my $str = shift;
	$str or return '';
	return &Ssm::Common::codeconv(Jcode->new($str)->h2z->tr($katakana, $hiragana)->euc, $main::charset);
}

####################################################

=pod

=head2 full_comapny_name()

=over 4

=item ǽ

˴ޤޤҷ֤άΡʡ()פͭ)פʤɡˤ̾Τ᤹
ҷ֤򼨤ʬȲ̾ʸδ֤ȾѥڡС

å/ȾѤѤƤȤϡȾѤ줵Ƥ
եϤ줿ͤꡣ

Ѵϡ.ssmrc  @abbr ǻǤ롣
.sscrcǤ˴ؤ餺֭ס֭ס֭סʤ1ʸˤ
줾ֳҡסֳҡסͭ²ҡפѴ롣

=item 

ʸ1ġ

=item 

Ѵʸ

=item 

$company_fullname = &full_comapny_name($company)

=back

=cut

sub full_comapny_name($){
	my $str = shift;
	my ($i, @special);
	if ($str){
		$str = Jcode->new($str)->euc;
		FINDABBR:for ($i=0; $i <= $#abbr; $i++){
			($str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?: *[\[\({<]? *$abbr[$i][1] *[\]\)}>]? *)/$1$abbr[$i][1]/
			or $str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?:(?: *[\[\({<] *$abbr[$i][0] *[\]\)}>] *)|(?: *$abbr[$i][0] *[\]\)}>] *)|(?: *[\[\({<] *$abbr[$i][0] *))/$1$abbr[$i][1]/)
			and last FINDABBR;
			if ($abbr[$i][1] eq ''){
				@special = qw/ /;
				foreach (@special){
					$str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?) *$_ */$1$abbr[$i][1]/
					and last FINDABBR;
				}
			} elsif ($abbr[$i][1] eq 'ͭ²'){
				@special = qw//;
				foreach (@special){
					$str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?) *$_ */$1$abbr[$i][1]/
					and last FINDABBR;
				}
			}
		}
	}
	return &Ssm::Common::codeconv($str, $main::charset);
}

####################################################

=pod

=head2 core_name()

=over 4

=item ǽ

˴ޤޤҷ֤򼨤ʸʡֳҡפ()סͭ)פʤɡˤ

ҷ֤򼨤ʬȲ̾ʸδ֤ȾѥڡС

å/ȾѤѤƤȤϡȾѤ줵Ƥ
եϤ줿ͤꡣ

Ѵϡ.ssmrc  @abbr ǻǤ롣
.sscrcǤ˴ؤ餺֭ס֭ס֭סʤ1ʸˤ

=item 

ʸ1ġ

=item 

ҷ֤򼨤ʬʸ

=item 

$core_comapny_name = &core_name($company)

=back

=cut

sub core_name($){
	my $str = shift;
	my ($i, @special);
	if ($str){
		$str = Jcode->new($str)->euc;
		FINDABBR:for ($i=0; $i <= $#abbr; $i++){
			($str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?: *[\[\({<]? *$abbr[$i][1] *[\]\)}>]? *)/$1/
			or $str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?:(?: *[\[\({<] *$abbr[$i][0] *[\]\)}>] *)|(?: *$abbr[$i][0] *[\]\)}>] *)|(?: *[\[\({<] *$abbr[$i][0] *))/$1/)
			and last FINDABBR;
			if ($abbr[$i][1] eq ''){
				@special = qw/ /;
				foreach (@special){
					$str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?) *$_ */$1/
					and last FINDABBR;
				}
			} elsif ($abbr[$i][1] eq 'ͭ²'){
				@special = qw//;
				foreach (@special){
					$str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?) *$_ */$1/
					and last FINDABBR;
				}
			}
		}
	}
	return &Ssm::Common::codeconv($str, $main::charset);
}

####################################################

=pod

=head2 core_comapny_yomi()

=over 4

=item ǽ

˴ޤޤȿ̤Υɽʡ֥楦󥬥פ֤)ˤ
ʸ󤫤
åѤƤȤϡȾѤ줵Ƥ
եϤ줿ͤѴꡣ

Ѵϡ.ssmrc  @abbr ǻǤ롣

=item 

ʸ1ġ

=item 

ȿ̤Υɽʸ

=item 

$core_yomi = &core_comapny_yomi($company_yomi)

=back

=cut

sub core_comapny_yomi($){
	my $str = shift;
	my ($i);
	if ($str){
		$str = Jcode->new($str)->euc;
		for ($i=0; $i <= $#abbr; $i++){
			($str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?: *[\[\({<]? *$abbr[$i][2] *[\]\)}>]? *)/$1/
			or $str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?:(?: *[\[\({<] *$abbr[$i][3] *[\]\)}>] *)|(?: *$abbr[$i][3] *[\]\)}>] *)|(?: *[\[\({<] *$abbr[$i][3] *))/$1/
			or $str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?:(?: *[\[\({<] *$abbr[$i][4] *[\]\)}>] *)|(?: *$abbr[$i][4] *[\]\)}>] *)|(?: *[\[\({<] *$abbr[$i][4] *))/$1/)
			and last;
		}
	}
	return &Ssm::Common::codeconv($str, $main::charset);
}

####################################################

=pod

=head2 if_all_katakana()

=over 4

=item ǽ

ѥʤΤߤǹƤ뤫å

=item 

ʸ1ġ

=item 

ѥʤΤ=1
¾ʸޤޤ=0

=item 

unless (&if_all_katakana($userinput) == 1){
	$errormsg = "ʤΤߤϤƲ";
}

=back

=cut

sub if_all_katakana($){
	my $str = shift;
	if ($str){
		$str = Jcode->new($str)->euc;
		$str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?:(?:$z_katakana|$z_ext)+)/$1/g;
	}
	if ($str eq '') {
		return 1;
	} else {
		return 0;
	}
}

####################################################

=pod

=head2 if_hiragana()

=over 4

=item ǽ

ѤҤ餬ʤΤߤǹƤ뤫å

=item 

ʸ1ġ

=item 

ѤҤ餬ʤΤ=1
¾ʸޤޤ=0

=item 

unless (&if_hiragana($userinput) == 1){
	$errormsg = "Ҥ餬ʤΤߤϤƲ";
}

=back

=cut

sub if_hiragana($){
	my $str = shift;
	if ($str){
		$str = Jcode->new($str)->euc;
		$str =~ s/\G((?:$ascii|$twoBytes|$threeBytes)*?)(?:(?:$z_hiragana|$z_ext)+)/$1/g;
	}
	if ($str eq '') {
		return 1;
	} else {
		return 0;
	}
}

####################################################

=pod

=head2 gen_unique_str()

=over 4

=item ǽ

դʸ롣
ѥʸκꡣ

=item 

͡ʸη330ʸꡣǥե=15
ʸ󡧻ѤʸϢ뤷ʸ
ǥե=abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890_

=item 

ʸ

=item 

$passwd = &gen_unique_str();

$alphabet_only = &gen_unique_str(8, 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ');


=back

=cut

sub gen_unique_str(;$$){ 
	#ʸĹǻ
	my ($length, $chars) = @_;
	my ($i, $tempval, $key, @chars);

	($length and $length =~ m/^\d+$/ and $length >= 3 and $length <= 30 ) or $length = 15;

	#Ѥʸ
	$chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890_' unless $chars;
	@chars = split(//, $chars);

	#Υͤ
	srand(time|$$);
	for ($i=0; $i<$length; $i++){
		# @chars κźޤǤ
		$tempval = int(rand(scalar(@chars)));
		$key .= $chars[$tempval];
	}
	return $key;
}


=head1 AUTHOR

  Copyright Miyabiko INOUE ( miy@web-ware.org )
  ̵ʣѡۤ뤳Ȥؤޤ

=head2 NOTES

  Further information: http://web-ware.org/

=head1 SEE ALSO

perl(1).

=cut


1;
